@@ -24,6 +24,7 @@ our @EXPORT_OK = qw(
   p_numeric_equals
   p_string_equals
   p_regex
+  p_substring
 );
 our %EXPORT_TAGS = (
   all      => [@EXPORT_OK],
@@ -149,7 +150,7 @@ sub p_ref_type {
       return 0 unless $ref;
       return ( $ref eq $ref_type ) ? 1 : 0;
     },
-    description => 'ref_type'
+    description => 'ref_type predicate with type '.$ref_type
   );
 }
 
@@ -161,7 +162,7 @@ sub p_isa {
       return 0 unless p_blessed()->apply($object);
       return ( $object->isa($isa) ) ? 1 : 0;
     },
-    description => 'isa'
+    description => 'isa predicate with type '.$isa
   );
 }
 
@@ -173,43 +174,59 @@ sub p_can {
       return 0 unless p_blessed()->apply($object);
       return ( $object->can($method) ) ? 1 : 0;
     },
-    description => 'can'
+    description => 'Can predicate with method '.$method
   );
 }
 
 sub p_string_equals {
   my ($str, $method) = @_;
+  my $target = (defined $method) ? "against method ${method}" : 'against values';
   return Data::Predicate::ClosurePredicate->new(
     closure => sub {
       my ($object) = @_;
       my $val = _invoke($object, $method);
       return ( p_defined->apply($val) && $val eq $str ) ? 1 : 0;
     },
-    description => 'string_equals'
+    description => "String equals predicate $target with number $str"
   );
 }
 
 sub p_numeric_equals {
   my ($number, $method) = @_;
+  my $target = (defined $method) ? "against method ${method}" : 'against values';
   return Data::Predicate::ClosurePredicate->new(
     closure => sub {
       my ($object) = @_;
       my $val = _invoke($object, $method);
       return ( p_is_number->apply($val) && $val == $number ) ? 1 : 0;
     },
-    description => 'numeric_equals'
+    description => "Numeric equals predicate $target with number $number"
   );
 }
 
 sub p_regex {
   my ($regex, $method) = @_;
+  my $target = (defined $method) ? "against method ${method}" : 'against values';
   return Data::Predicate::ClosurePredicate->new(
     closure => sub {
       my ($object) = @_;
       my $val = _invoke($object, $method);
       return ( p_defined->apply($val) && $val =~ $regex) ? 1 : 0;
     },
-    description => 'regex'
+    description => "Regular expression predicate $target with regex $regex"
+  );
+}
+
+sub p_substring {
+  my ($substring, $method) = @_;
+  my $target = (defined $method) ? "against method ${method}" : 'against values';
+  return Data::Predicate::ClosurePredicate->new(
+    closure => sub {
+      my ($object) = @_;
+      my $val = _invoke($object, $method);
+      return ( p_defined->apply($val) && index($val, $substring) > -1) ? 1 : 0;
+    },
+    description => "Substring predicate $target with substring $substring"
   );
 }
 
@@ -427,6 +444,25 @@ supplementing it with a subroutine to run the match on. This does not apply
 any numeric tests since it's quite valid to regex against a number. However
 it will return false if the value retrieved or evaluated was undefined.
 
+=head2 p_substring()
+
+  p_substring('world')->apply('hello world'); #returns true
+  p_substring('o')->apply('hello world'); #returns true
+  p_substring('goodbye')->apply('hello world'); #returns false
+  
+  #Again assume our Dog object returns arrooowww
+  p_substring('ooo', 'howl')->apply($dog);
+
+This is another type of test which when looking for substrings is far more
+performant than using C<p_regex()>. The logic is to use your first variable
+as the substring to look for in the given value. If the index is greater than
+-1 we return true.
+
+In micro-benchmarks we can see a 4x improvement in speed in using the
+substring style predicate over using regular expressions. Substring
+also has the advantage that you cannot have your substring mis-interpreted
+as a regular expression control character e.g. a period or braces
+
 =head1 DEPENDENCIES
 
 =over 8
